--[[
	Titan Plugin:   Turtle: Rested XP
	Description:    Rested XP Tracker for Turtle Wow
    Note:           This should work everywhere but, other servers may not have the same
                    max rested xp cap screwing up the calculations
    Author:         Quiver
    Date:           03/30/2021

    Dedicated to Turtle Wow, the best custom vanilla World of Warcraft server.
    Websiite:       http://turtle-wow.org
    Discord:        https://discord.com/invite/mBGxmHy
--]]

TITAN_RESTED_MENU_TEXT = "Turtle: Rested XP"
TITAN_RESTED_ID        = "Rested"
TITAN_RESTED_FREQUENCY = 0.5

local TitanRestedName    = "TitanRested"
local TitanRestedVersion = "1.0.0"

function TitanPanelRestedButton_OnLoad()
	this.registry = {
		id           = TITAN_RESTED_ID,
		menuText     = TITAN_RESTED_MENU_TEXT,
		tooltipTitle = TITAN_RESTED_ID,
		frequency    = TITAN_RESTED_FREQUENCY,
		icon         = "Interface\\Icons\\inv_misc_pocketwatch_02.blp",
		iconWidth    = 16,
		category     = "Information",
		savedVariables = {
			ShowIcon   = 1,
            isCompact  = 1
		},
        buttonTextFunction  = "TitanPanelRestedButton_GetButtonText",
		tooltipTextFunction = "TitanPanelRestedButton_GetTooltipText"
	}
end

function TitanPanelRestedButton_GetButtonText(id)
    rested      = GetXPExhaustion()
    compactMode = TitanGetVar(TITAN_RESTED_ID, "isCompact")
    maxRest     = UnitXPMax("player") * 1.5
    msg         = "Rested: |cFFFFFFFF"

    if (compactMode) then
        if UnitLevel("player") == 60 then
            msg = msg .. "100%"
        else
            if -1==(rested or -1) then 
                msg = msg .. "0%"
            else    
                msg = msg .. math.floor((rested * 100) / maxRest) .. "%"
            end
        end
    else
        if UnitLevel("player") == 60 then
            msg = msg .. "You are |cFFFF0000immortal|cFFFFFFFF, you do not require rest!"
        else
            if -1==(rested or -1) then 
                msg = msg .. "You are not rested, you need a nap!"
            else    
                if percent == 100 then
                    msg = msg .. "Fully rested!"
                else
                    msg = msg .. "|cFFFFFF00" .. rested .. "|cFFFFFFFF of |cFFFFFF00" .. maxRest .. "|cFFFFFFFF (|cFF22efc4" .. math.floor((rested * 100) / maxRest) .. "%|cFFFFFFFF)"
                end
            end
        end
    end
    
    return msg
end

function TitanPanelRestedButton_GetTooltipText()
	return "Displays your current rested percent "..TitanUtils_GetGreenText("Use: Right-click for options.")
end

function TitanPanelRestedButton_OnUpdate(arg1)
    TitanPanelButton_UpdateButton(TITAN_RESTED_ID)
end

function TitanPanelRightClickMenu_PrepareRestedMenu()
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_RESTED_ID].menuText)
    TitanPanelRightClickMenu_AddToggleVar("Compact Mode", TITAN_RESTED_ID, "isCompact") 
    TitanPanelRightClickMenu_AddSpacer()
    TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_HIDE, TITAN_RESTED_ID, TITAN_PANEL_MENU_FUNC_HIDE)
end 
